inla_rspde objectsFunction to get the precision matrix of an inla_rspde object created with the rspde.matern() function.
# S3 method for inla_rspde
precision(object, theta = NULL, ...)The precision matrix.
The inla_rspde object obtained with the rspde.matern() function.
If null, the starting values for theta will be used. Otherwise, it must be suplied as a vector.
For stationary models, we have theta = c(log(tau), log(kappa), nu). For nonstationary models, we have
theta = c(theta_1, theta_2, ..., theta_n, nu).
Currently not used.
precision.CBrSPDEobj(), matern.operators()