Creates an INLA object for a stationary Matern model with general smoothness parameter.
Usage
rspde.matern(
mesh,
nu.upper.bound = NULL,
rspde.order = 1,
nu = NULL,
B.sigma = matrix(c(0, 1, 0), 1, 3),
B.range = matrix(c(0, 0, 1), 1, 3),
parameterization = c("spde", "matern", "matern2"),
B.tau = matrix(c(0, 1, 0), 1, 3),
B.kappa = matrix(c(0, 0, 1), 1, 3),
start.nu = NULL,
start.theta = NULL,
prior.nu = NULL,
theta.prior.mean = NULL,
theta.prior.prec = 0.1,
prior.std.dev.nominal = 1,
prior.range.nominal = NULL,
prior.kappa.mean = NULL,
prior.tau.mean = NULL,
start.lstd.dev = NULL,
start.lrange = NULL,
start.ltau = NULL,
start.lkappa = NULL,
prior.theta.param = c("theta", "spde"),
prior.nu.dist = c("beta", "lognormal"),
nu.prec.inc = 1,
type.rational.approx = c("brasil", "chebfun", "chebfunLB"),
debug = FALSE,
shared_lib = "detect",
...
)Arguments
- mesh
The mesh to build the model. It can be an
inla.meshor aninla.mesh.1dobject. Otherwise, should be a list containing elements d, the dimension, C, the mass matrix, and G, the stiffness matrix.- nu.upper.bound
Upper bound for the smoothness parameter. If
NULL, it will be set to 2.- rspde.order
The order of the covariance-based rational SPDE approach. The default order is 1.
- nu
If nu is set to a parameter, nu will be kept fixed and will not be estimated. If nu is
NULL, it will be estimated.- B.sigma
Matrix with specification of log-linear model for \(\sigma\) (for 'matern' parameterization) or for \(\sigma^2\) (for 'matern2' parameterization). Will be used if
parameterization = 'matern'orparameterization = 'matern2'.- B.range
Matrix with specification of log-linear model for \(\rho\), which is a range-like parameter (it is exactly the range parameter in the stationary case). Will be used if
parameterization = 'matern'orparameterization = 'matern2'.- parameterization
Which parameterization to use?
maternuses range, std. deviation and nu (smoothness).spdeuses kappa, tau and nu (smoothness).matern2uses range-like (1/kappa), variance and nu (smoothness). The default isspde.- B.tau
Matrix with specification of log-linear model for \(\tau\). Will be used if
parameterization = 'spde'.- B.kappa
Matrix with specification of log-linear model for \(\kappa\). Will be used if
parameterization = 'spde'.- start.nu
Starting value for nu.
- start.theta
Starting values for the model parameters. In the stationary case, if
parameterization='matern', thentheta[1]is the std.dev andtheta[2]is the range parameter. Ifparameterization = 'spde', thentheta[1]istauandtheta[2]iskappa.- prior.nu
a list containing the elements
meanandprecfor beta distribution, orloglocationandlogscalefor a truncated lognormal distribution.loglocationstands for the location parameter of the truncated lognormal distribution in the log scale.precstands for the precision of a beta distribution.logscalestands for the scale of the truncated lognormal distribution on the log scale. Check details below.- theta.prior.mean
A vector for the mean priors of
theta.- theta.prior.prec
A precision matrix for the prior of
theta.- prior.std.dev.nominal
Prior std. deviation to be used for the priors and for the starting values.
- prior.range.nominal
Prior range to be used for the priors and for the starting values.
- prior.kappa.mean
Prior kappa to be used for the priors and for the starting values.
- prior.tau.mean
Prior tau to be used for the priors and for the starting values.
- start.lstd.dev
Starting value for log of std. deviation. Will not be used if start.ltau is non-null. Will be only used in the stationary case and if
parameterization = 'matern'.- start.lrange
Starting value for log of range. Will not be used if start.lkappa is non-null. Will be only used in the stationary case and if
parameterization = 'matern'.- start.ltau
Starting value for log of tau. Will be only used in the stationary case and if
parameterization = 'spde'.- start.lkappa
Starting value for log of kappa. Will be only used in the stationary case and if
parameterization = 'spde'.- prior.theta.param
Should the lognormal prior be on
thetaor on the SPDE parameters (tauandkappaon the stationary case)?- prior.nu.dist
The distribution of the smoothness parameter. The current options are "beta" or "lognormal". The default is "lognormal".
- nu.prec.inc
Amount to increase the precision in the beta prior distribution. Check details below.
- type.rational.approx
Which type of rational approximation should be used? The current types are "brasil", "chebfun" or "chebfunLB".
- debug
INLA debug argument
Which shared lib to use for the cgeneric implementation?
"detect"and"INLA"prefer the model compiled into the INLA binary and fall back to a compiled local rSPDE library when the symbol is unavailable."rSPDE"requires the local library. An existing.soor.dllpath can also be supplied directly.- ...
Only being used internally.
- prior.kappa
a
listcontaining the elementsmeanlogandsdlog, that is, the mean and standard deviation on the log scale.- prior.tau
a list containing the elements
meanlogandsdlog, that is, the mean and standard deviation on the log scale.- prior.range
a
listcontaining the elementsmeanlogandsdlog, that is, the mean and standard deviation on the log scale. Will not be used if prior.kappa is non-null.- prior.std.dev
a
listcontaining the elementsmeanlogandsdlog, that is, the mean and standard deviation on the log scale. Will not be used if prior.tau is non-null.