rSPDE inlabru mapper
Source:R/inla_rspde_intrinsic.R, R/inlabru_rspde.R
bru_get_mapper.inla_rspde.RdrSPDE inlabru mapper
Usage
ibm_n.bru_mapper_inla_rspde_fintrinsic(mapper, ...)
ibm_values.bru_mapper_inla_rspde_fintrinsic(mapper, ...)
ibm_jacobian.bru_mapper_inla_rspde_fintrinsic(mapper, input, ...)
bru_get_mapper.inla_rspde(model, ...)
ibm_n.bru_mapper_inla_rspde(mapper, ...)
ibm_values.bru_mapper_inla_rspde(mapper, ...)
ibm_jacobian.bru_mapper_inla_rspde(mapper, input, ...)Examples
# \donttest{
# devel version
if (requireNamespace("INLA", quietly = TRUE) &&
requireNamespace("inlabru", quietly = TRUE)) {
library(INLA)
library(inlabru)
set.seed(123)
m <- 100
loc_2d_mesh <- matrix(runif(m * 2), m, 2)
mesh_2d <- inla.mesh.2d(
loc = loc_2d_mesh,
cutoff = 0.05,
max.edge = c(0.1, 0.5)
)
sigma <- 1
range <- 0.2
nu <- 0.8
kappa <- sqrt(8 * nu) / range
op <- matern.operators(
mesh = mesh_2d, nu = nu,
range = range, sigma = sigma, m = 2,
parameterization = "matern"
)
u <- simulate(op)
A <- inla.spde.make.A(
mesh = mesh_2d,
loc = loc_2d_mesh
)
sigma.e <- 0.1
y <- A %*% u + rnorm(m) * sigma.e
y <- as.vector(y)
data_df <- data.frame(
y = y, x1 = loc_2d_mesh[, 1],
x2 = loc_2d_mesh[, 2]
)
rspde_model <- rspde.matern(
mesh = mesh_2d,
nu_upper_bound = 2
)
cmp <- y ~ Intercept(1) +
field(cbind(x1,x2), model = rspde_model)
rspde_fit <- bru(cmp, data = data_df)
summary(rspde_fit)
}
#>
#> Warning: `inla.mesh.2d()` was deprecated in INLA 23.08.18.
#> ℹ Please use `fmesher::fm_mesh_2d_inla()` instead.
#> ℹ For more information, see
#> https://inlabru-org.github.io/fmesher/articles/inla_conversion.html
#> ℹ To silence these deprecation messages in old legacy code, set
#> `inla.setOption(fmesher.evolution.warn = FALSE)`.
#> ℹ To ensure visibility of these messages in package tests, also set
#> `inla.setOption(fmesher.evolution.verbosity = 'warn')`.
#> inlabru version: 2.15.0
#> INLA version: 26.08.07
#> Latent components:
#> Intercept: main = linear(1)
#> field: main = cgeneric(cbind(x1, x2))
#> Observation models:
#> Model tag: <No tag>
#> Family: 'gaussian'
#> Data class: 'data.frame'
#> Response class: 'numeric'
#> Predictor: y ~ Intercept + field
#> Additive/Linear/Rowwise: TRUE/TRUE/TRUE
#> Used components: effect[Intercept, field], latent[]
#> Time used:
#> Pre = 0.682, Running = 1.51, Post = 0.0687, Total = 2.26
#> Fixed effects:
#> mean sd 0.025quant 0.5quant 0.975quant mode kld
#> Intercept 0.305 0.165 -0.023 0.305 0.634 0.305 0
#>
#> Random effects:
#> Name Model
#> field CGeneric
#>
#> Model hyperparameters:
#> mean sd 0.025quant 0.5quant
#> Precision for the Gaussian observations 129.30 79.901 21.91 111.68
#> Theta1 for field -10.41 6.256 -25.25 -9.38
#> Theta2 for field 3.47 0.627 2.59 3.39
#> Theta3 for field 3.49 3.422 -1.14 2.93
#> 0.975quant mode
#> Precision for the Gaussian observations 321.24 66.804
#> Theta1 for field -1.95 -3.998
#> Theta2 for field 4.95 2.875
#> Theta3 for field 11.61 -0.013
#>
#> Marginal log-Likelihood: -106.40
#> is computed
#> Posterior summaries for the linear predictor and the fitted values are computed
#> (Posterior marginals needs also 'control.compute=list(return.marginals.predictor=TRUE)')
#>
# devel.tag
# }