rSPDE inlabru mapper
Source:R/inla_rspde_intrinsic.R, R/inlabru_rspde.R
bru_get_mapper.inla_rspde.RdrSPDE inlabru mapper
Usage
ibm_n.bru_mapper_inla_rspde_fintrinsic(mapper, ...)
ibm_values.bru_mapper_inla_rspde_fintrinsic(mapper, ...)
ibm_jacobian.bru_mapper_inla_rspde_fintrinsic(mapper, input, ...)
bru_get_mapper.inla_rspde(model, ...)
ibm_n.bru_mapper_inla_rspde(mapper, ...)
ibm_values.bru_mapper_inla_rspde(mapper, ...)
ibm_jacobian.bru_mapper_inla_rspde(mapper, input, ...)Examples
# \donttest{
# devel version
if (requireNamespace("INLA", quietly = TRUE) &&
requireNamespace("inlabru", quietly = TRUE)) {
library(INLA)
library(inlabru)
set.seed(123)
m <- 100
loc_2d_mesh <- matrix(runif(m * 2), m, 2)
mesh_2d <- inla.mesh.2d(
loc = loc_2d_mesh,
cutoff = 0.05,
max.edge = c(0.1, 0.5)
)
sigma <- 1
range <- 0.2
nu <- 0.8
kappa <- sqrt(8 * nu) / range
op <- matern.operators(
mesh = mesh_2d, nu = nu,
range = range, sigma = sigma, m = 2,
parameterization = "matern"
)
u <- simulate(op)
A <- inla.spde.make.A(
mesh = mesh_2d,
loc = loc_2d_mesh
)
sigma.e <- 0.1
y <- A %*% u + rnorm(m) * sigma.e
y <- as.vector(y)
data_df <- data.frame(
y = y, x1 = loc_2d_mesh[, 1],
x2 = loc_2d_mesh[, 2]
)
rspde_model <- rspde.matern(
mesh = mesh_2d,
nu_upper_bound = 2
)
cmp <- y ~ Intercept(1) +
field(cbind(x1,x2), model = rspde_model)
rspde_fit <- bru(cmp, data = data_df)
summary(rspde_fit)
}
#>
#> Warning: `inla.mesh.2d()` was deprecated in INLA 23.08.18.
#> ℹ Please use `fmesher::fm_mesh_2d_inla()` instead.
#> ℹ For more information, see
#> https://inlabru-org.github.io/fmesher/articles/inla_conversion.html
#> ℹ To silence these deprecation messages in old legacy code, set
#> `inla.setOption(fmesher.evolution.warn = FALSE)`.
#> ℹ To ensure visibility of these messages in package tests, also set
#> `inla.setOption(fmesher.evolution.verbosity = 'warn')`.
#> inlabru version: 2.14.1
#> INLA version: 26.05.10
#> Latent components:
#> Intercept: main = linear(1)
#> field: main = cgeneric(cbind(x1, x2))
#> Observation models:
#> Model tag: <No tag>
#> Family: 'gaussian'
#> Data class: 'data.frame'
#> Response class: 'numeric'
#> Predictor: y ~ Intercept + field
#> Additive/Linear/Rowwise: TRUE/TRUE/TRUE
#> Used components: effect[Intercept, field], latent[]
#> Time used:
#> Pre = 0.332, Running = 1.26, Post = 0.416, Total = 2.01
#> Fixed effects:
#> mean sd 0.025quant 0.5quant 0.975quant mode kld
#> Intercept 0.305 0.168 -0.028 0.305 0.64 0.305 0
#>
#> Random effects:
#> Name Model
#> field CGeneric
#>
#> Model hyperparameters:
#> mean sd 0.025quant 0.5quant
#> Precision for the Gaussian observations 163.622 80.696 51.640 148.46
#> Theta1 for field -3.903 0.514 -5.075 -3.84
#> Theta2 for field 2.885 0.202 2.501 2.88
#> Theta3 for field -0.092 0.272 -0.528 -0.12
#> 0.975quant mode
#> Precision for the Gaussian observations 361.018 119.157
#> Theta1 for field -3.103 -3.548
#> Theta2 for field 3.296 2.860
#> Theta3 for field 0.522 -0.259
#>
#> Marginal log-Likelihood: -108.72
#> is computed
#> Posterior summaries for the linear predictor and the fitted values are computed
#> (Posterior marginals needs also 'control.compute=list(return.marginals.predictor=TRUE)')
#>
# devel.tag
# }