rSPDE inlabru mapper
bru_get_mapper.intrinsic_matern(model, ...)ibm_n.bru_mapper_intrinsic_matern(mapper, ...)
ibm_values.bru_mapper_intrinsic_matern(mapper, ...)
ibm_jacobian.bru_mapper_intrinsic_matern(mapper, input, ...)
An intrinsic_matern object for which to construct or extract a mapper
Arguments passed on to other methods
A bru_mapper_intrinsic_matern object
The values for which to produce a mapping matrix